pub enum JsonStructureSettings {
Structured(Option<StructType>),
UnstructuredRaw,
PartialUnstructuredByKey {
fields: Option<StructType>,
unstructured_keys: HashSet<String>,
},
}Expand description
The configuration of JSON encoding
The enum describes how we handle JSON encoding to StructValue internally.
It defines three configurations:
- Structured: Encodes JSON objects as StructValue with an optional predefined StructType.
- UnstructuredRaw: Encodes JSON data as string and store it in a struct with a field named “_raw”.
- PartialUnstructuredByKey: Encodes JSON objects as StructValue with an optional predefined StructType
and a set of unstructured keys, these keys are provided as flattened names, for example:
a.b.c.
We provide a few methods to convert JSON data to StructValue based on the settings. And we also convert them to fully structured StructValue for user-facing APIs: the UI protocol and the UDF interface.
Important: This settings only controls the internal form of JSON encoding.
Variants
Implementations
Sourceimpl JsonStructureSettings
impl JsonStructureSettings
pub const RAW_FIELD: &'static str = "_raw"
Sourcepub fn decode(&self, value: Value) -> Result<Json>
pub fn decode(&self, value: Value) -> Result<Json>
Decode an encoded StructValue back into a serde_json::Value.
Sourcepub fn decode_struct(&self, struct_value: StructValue) -> Result<StructValue>
pub fn decode_struct(&self, struct_value: StructValue) -> Result<StructValue>
Decode a StructValue that was encoded with current settings back into a fully structured StructValue. This is useful for reconstructing the original structure from encoded data, especially when unstructured encoding was used for some fields.
Sourcepub fn encode(&self, json: Json) -> Result<Value>
pub fn encode(&self, json: Json) -> Result<Value>
Encode a serde_json::Value into a Value::Json using current settings.
Sourcepub fn encode_with_type(
&self,
json: Json,
data_type: Option<&JsonNativeType>,
) -> Result<Value>
pub fn encode_with_type( &self, json: Json, data_type: Option<&JsonNativeType>, ) -> Result<Value>
Encode a serde_json::Value into a Value::Json with given data type.
fn json_struct(&self) -> Option<&StructType>