fn encode_json_value_with_context(
json: Value,
context: &mut JsonContext<'_>,
) -> Result<JsonValue>Expand description
Helper function to encode a JSON value to a Value and determine its ConcreteDataType with context
fn encode_json_value_with_context(
json: Value,
context: &mut JsonContext<'_>,
) -> Result<JsonValue>Helper function to encode a JSON value to a Value and determine its ConcreteDataType with context