fn encode_json_value_with_context<'a>(
json: Value,
context: &JsonContext<'a>,
) -> Result<JsonValue>Expand description
Helper function to encode a JSON value to a Value and determine its ConcreteDataType with context
fn encode_json_value_with_context<'a>(
json: Value,
context: &JsonContext<'a>,
) -> Result<JsonValue>Helper function to encode a JSON value to a Value and determine its ConcreteDataType with context